@@ -32,20 +32,22 @@ class VisitorTrackingMiddleware(object):
 
     def __init__(self):
         """Process the settings before handling the first request."""
-
         # get a list of URL prefixes that should not be tracked.
         self.prefixes = settings.NO_TRACKING_PREFIXES
+        log.info(settings.MEDIA_URL)
         if settings.MEDIA_URL and settings.MEDIA_URL != '/':
             self.prefixes.append(settings.MEDIA_URL)
         if settings.STATIC_URL and settings.STATIC_URL != '/':
             self.prefixes.append(settings.STATIC_URL)
 
+        log.debug('Processed user tracking settings successfully. '
+                  'Ready to handle new visitors.')
+
     def process_request(self, request):
         # don't process AJAX requests
         if request.is_ajax():
             return
 
-        # create some useful variables
         ip_address = utils.get_ip(request)
         user_agent = request.META.get('HTTP_USER_AGENT', '')[:255]
 
@@ -81,7 +83,6 @@ class VisitorTrackingMiddleware(object):
                 return
 
         # if we get here, the URL needs to be tracked
-        # determine what time it is
         now = datetime.now()
 
         attributes = {
@@ -89,7 +90,7 @@ class VisitorTrackingMiddleware(object):
             'ip_address': ip_address
         }
 
-        # for some reason, Visitor.objects.get_or_create was not working here
+        # see if this is a known visitor, or create a new entry
         try:
             visitor = Visitor.objects.get(**attributes)
         except Visitor.DoesNotExist:
@@ -127,8 +128,8 @@ class VisitorTrackingMiddleware(object):
         # at least an hour, update their referrer URL
         one_hour_ago = now - timedelta(hours=1)
         if not visitor.last_update or visitor.last_update <= one_hour_ago:
-            visitor.referrer = utils.u_clean(
-                request.META.get('HTTP_REFERER', 'unknown')[:255])
+            visitor.referrer = request.META.get('HTTP_REFERER',
+                                                'unknown')[:255]
 
             # reset the number of pages they've been to
             visitor.page_views = 0
@@ -147,9 +148,8 @@ class VisitorTrackingMiddleware(object):
 class VisitorCleanUpMiddleware:
     """Clean up old visitor tracking records in the database"""
 
-    @staticmethod
-    def process_request(request):
-        timeout = utils.get_cleanup_timeout()
+    def process_request(self, request):
+        timeout = settings.TRACKING_CLEANUP_TIMEOUT
 
         if str(timeout).isdigit():
             log.debug('Cleaning up visitors older than %s hours' % timeout)
